@@ -27,6 +27,7 @@ class Potential():
     def __sub__(self,a): return self + (-1)*a
     def __rsub__(self,a): return -self + a
     def __radd__(self,a): return self + a
+    def __truediv__(self,a): return self*(1./a)
     def __call__(self,r):
         return self.f(r)
     def normalize(self):
@@ -88,7 +89,7 @@ def commensurate_potential(g,k=1,amplitude=1.0,n=None,
         if 0.49<abs(a12)<0.51: n = 6
         elif abs(a12)<0.01: n = 4
         else: n = 3
-      f = cnpot(n=n,k=g.b1,**kwargs)
+      f = cnpot(n=n,k=k*g.b1,**kwargs)
     elif g.dimensionality==1: 
       f = cnpot(n=1,k=k*g.b1,**kwargs)
     else: raise
@@ -100,7 +101,13 @@ def commensurate_potential(g,k=1,amplitude=1.0,n=None,
     return f
 
 
-
+def impurity(r0,v=0.):
+    """Create the potential for an impurity"""
+    def f(r):
+        dr = r-r0
+        if dr.dot(dr)<1e-3: return v
+        else: return 0.
+    return Potential(f) # return the potential
 
 
 
