@@ -73,10 +73,8 @@ def SOC_TMDC(g=None,soc=0.0,**kwargs):
 
 
 def NbSe2(**kwargs):
-#    return TMDC_MX2(**kwargs,ts=[0.0263,0.0991,-0.0014,-0.0112,-0.0146,0.0025])
     return TMDC_MX2(**kwargs,
             tij=[0.02126916,  0.08462639,  0.00504899, -0.00906057, -0.00572983])
-#    return TMDC_MX2(**kwargs,ts=[0.3,2.,0.6,0.2,0.])
 
 def TaS2(**kwargs):
     return TMDC_MX2(**kwargs,
@@ -178,24 +176,41 @@ def excitonic_bilayer(gap=0.0,g=None,**kwargs):
 
 
 
-def FeSe():
+def FeSe(nem=0.,**kwargs):
     """Return the Hamiltonian of FeSe, a bandstructure
     displaying two pockets"""
-    g = geometry.cubic_lattice() # cubic lattice
-    g = g.supercell([1,1,2]) # create a bilayer
-    g.dimensionality = 2 # set as 2d
-    g.center()
-    def fh(r1,r2): # function for the hoppings
-        dr = r1-r2
-        dr2 = dr.dot(dr)
-        if 0.9<dr2<1.1:
-            if abs(dr[2])>0.1: return 0. # no hopping
-            if np.sign(r1[2]+r2[2])>0: return 1.0 # return hopping
-            else: return -1.0 
-        return 0.
-    h = g.get_hamiltonian(tij=fh)
-    h.add_onsite(lambda r: 3.+1*r[2])
+    g = geometry.square_lattice() # cubic lattice
+    h = g.get_hamiltonian(tij=[1.,3.],**kwargs) 
+#    h = g.get_hamiltonian(tij=[1.,-0.4,0.4],**kwargs) 
+    h.add_onsite(-5.)
+#    h.add_onsite(-2.5)
+    v = np.array([1.,0.,0.]) # nematic vector
+    v = v/np.sqrt(v.dot(v))
+#    h.remove_spin()
+    def fnem(dr):
+        if dr.dot(dr)>1e-2: dr = dr/np.sqrt(dr.dot(dr)) # unitary vector
+        else: return 1.0 # same site
+        o = 1. - nem*(dr.dot(v)**2-0.5) # return 
+        return o
+    if np.abs(nem)>0.:
+      h.add_strain(fnem, mode="directional")
+    h.turn_dense()
     return h
+#    g = geometry.cubic_lattice() # cubic lattice
+#    g = g.supercell([1,1,2]) # create a bilayer
+#    g.dimensionality = 2 # set as 2d
+#    g.center()
+#    def fh(r1,r2): # function for the hoppings
+#        dr = r1-r2
+#        dr2 = dr.dot(dr)
+#        if 0.9<dr2<1.1:
+#            if abs(dr[2])>0.1: return 0. # no hopping
+#            if np.sign(r1[2]+r2[2])>0: return 1.0 # return hopping
+#            else: return -1.0 
+#        return 0.
+#    h = g.get_hamiltonian(tij=fh)
+#    h.add_onsite(lambda r: 3.+1*r[2])
+#    return h
 
 
 
